var apiHost = "http://server-aimg1.nuoyea.com";
module.exports = {
	// HTTP请求
	http(options, callback) {
		const url = options.hasOwnProperty('url') ? options.url : "";
		const method = options.hasOwnProperty('method') ? options.method : "GET";
		const data = options.hasOwnProperty('data') ? options.data : {};
		const timeout = options.hasOwnProperty('timeout') ? options.timeout : 15 * 1000;
		const header = options.hasOwnProperty('header') ? options.header : {};

		uni.request({
			method,
			url,
			data,
			timeout,
			header,
			success: (res) => {
				if (typeof(callback) === "function") {
					callback({
						success: true,
						msg: "成功",
						data: res.data
					})
				}
			},
			fail: () => {
				if (typeof(callback) === "function") {
					callback({
						success: false,
						msg: "调用请求接口失败",
						data: {}
					})
				}
			}
		});
	},
	// 发送短信验证码
	SendSMSVerifyCode(mobile, callback) {
		this.http({
			url: `${apiHost}/user/SendSMSVerifyCode`,
			data: {
				mobile
			}
		}, (e) => {
			if (!e.success) {
				callback && callback({
					success: false,
					msg: e.msg || '接口错误',
					code: 0,
				});
			} else {
				try {
					callback && callback({
						success: e.data.Success,
						msg: e.data.Msg,
						code: e.data.Code,
					});
				} catch (err) {
					callback && callback({
						success: false,
						msg: '接口返回数据有误',
						code: 0,
					});
				}
			}
		});
	},
	// 注册并登录
	Login(mobile, verifyCode, callback) {
		this.http({
			url: `${apiHost}/user/Login`,
			data: {
				mobile,
				verifyCode
			}
		}, (e) => {
			if (!e.success) {
				callback && callback({
					success: false,
					msg: e.msg || '接口错误',
					code: 0,
					avatarUrl: "",
					nick: "",
					token: ""
				});
			} else {
				try {
					callback && callback({
						success: e.data.Success,
						msg: e.data.Msg,
						code: e.data.Code,
						avatarUrl: e.data.AvatarUrl,
						nick: e.data.Nick,
						token: e.data.Token
					});
				} catch (err) {
					callback && callback({
						success: false,
						msg: '接口返回数据有误',
						code: 0,
						avatarUrl: "",
						nick: "",
						token: ""
					});
				}
			}
		});
	},
	// AI绘图
	AIDraw(token, text, style, resolution, num, callback) {
		this.http({
			method: "POST",
			url: `${apiHost}/user/AIDraw`,
			data: {
				token,
				text,
				style,
				resolution,
				num
			}
		}, (e) => {
			if (!e.success) {
				callback && callback({
					success: false,
					msg: e.msg || '接口错误',
					code: 0,
					taskID: 0,
					logID: 0
				});
			} else {
				try {
					callback && callback({
						success: e.data.Success,
						msg: e.data.Msg,
						code: e.data.Code,
						taskID: e.data.TaskID,
						logID: e.data.LogID
					});
				} catch (err) {
					callback && callback({
						success: false,
						msg: '接口返回数据有误',
						code: 0,
						taskID: 0,
						logID: 0
					});
				}
			}
		});
	},
	// 查询AI绘图结果
	AIDrawRes(taskId, callback) {
		this.http({
			url: `${apiHost}/user/AIDrawRes`,
			data: {
				taskId
			}
		}, (e) => {
			if (!e.success) {
				callback && callback({
					success: false,
					msg: e.msg || '接口错误',
					code: 0,
					imgUrls: [],
					waiting: "",
				});
			} else {
				try {
					callback && callback({
						success: e.data.Success,
						msg: e.data.Msg,
						code: e.data.Code,
						imgUrls: e.data.Data.ImgUrls || [],
						waiting: e.data.Data.Waiting,
					});
				} catch (err) {
					callback && callback({
						success: false,
						msg: '接口返回数据有误',
						code: 0,
						imgUrls: [],
						waiting: "",
					});
				}
			}
		});
	},
	// 获取全网生成历史
	GetInternetHistory(callback) {
		this.http({
			url: `${apiHost}/user/GetInternetHistory`,
		}, (e) => {
			if (!e.success) {
				callback && callback({
					success: false,
					msg: e.msg || '接口错误',
					code: 0,
					history: []
				});
			} else {
				try {
					callback && callback({
						success: e.data.Success,
						msg: e.data.Msg,
						code: e.data.Code,
						history: e.data.History
					});
				} catch (err) {
					callback && callback({
						success: false,
						msg: '接口返回数据有误',
						code: 0,
						history: []
					});
				}
			}
		});
	},
	// ========================================================================
	// 注册查询
	RegisterAndQueryAccount(user, password, callback) {
		this.http({
			url: apiHost + "/RegisterAndQueryAccount",
			data: {
				user,
				password
			}
		}, (e) => {
			if (!e.success) {
				if (typeof(callback) == "function") callback({
					success: e.success,
					msg: e.msg,
					point: 0,
					authorize: 0,
				});
				return;
			};
			try {
				if (typeof(callback) == "function") callback({
					success: e.data.success,
					msg: e.data.msg,
					point: e.data.point,
					authorize: e.data.authorize,
				});
			} catch (err) {
				if (typeof(callback) == "function") callback({
					success: false,
					msg: "接口返回数据有误",
					point: 0,
					authorize: 0,
				});
			};
		});
	},
	// 卡密充值
	TopUpAccount(user, password, cdkey, callback) {
		this.http({
			url: apiHost + "/TopUpAccount",
			data: {
				user,
				password,
				cdkey
			}
		}, (e) => {
			if (!e.success) {
				if (typeof(callback) == "function") callback({
					success: e.success,
					msg: e.msg
				});
				return;
			};
			try {
				if (typeof(callback) == "function") callback({
					success: e.data.success,
					msg: e.data.msg
				});
			} catch (err) {
				if (typeof(callback) == "function") callback({
					success: false,
					msg: "接口返回数据有误"
				});
			};
		});
	},
	// 设备授权
	AuthorizeDevice(user, password, machineCode, callback) {
		this.http({
			url: apiHost + "/AuthorizeDevice",
			data: {
				user,
				password,
				machineCode
			}
		}, (e) => {
			if (!e.success) {
				if (typeof(callback) == "function") callback({
					success: e.success,
					msg: e.msg
				});
				return;
			};
			try {
				if (typeof(callback) == "function") callback({
					success: e.data.success,
					msg: e.data.msg
				});
			} catch (err) {
				if (typeof(callback) == "function") callback({
					success: false,
					msg: "接口返回数据有误"
				});
			};
		});
	},
};