module.exports = {
	// 返回上一页 - 若无法返回上一页，则跳转到到指定页面
	navigate_back(url) {
		const currentPageNum = getCurrentPages().length;
		if (currentPageNum <= 1 && typeof url === 'string' && url.length > 0) {
			uni.switchTab({
				url,
			});
		} else {
			uni.navigateBack();
		}
	},
	/* 获取系统窗口大小 */
	getWindowSize(callback) {
		const windowSize = uni.getWindowInfo();
		if (typeof(callback) == 'function') {
			callback(windowSize);
		};
	},
	// 简单模态弹窗
	briefModal(content, callback) {
		uni.showModal({
			content,
			showCancel: false,
			confirmText: '確認',
			confirmColor: '#ed7182',
			success: function(res) {
				if (typeof(callback) == "function") callback();
			}
		});
	},
	// 高级模态弹窗
	advancedModal(content, confirmText, callback) {
		uni.showModal({
			content,
			showCancel: true,
			cancelText: '取消',
			confirmText: confirmText,
			confirmColor: '#ed7182',
			success: function(res) {
				if (res.confirm) {
					if (typeof(callback) == "function") callback(true);
				} else if (res.cancel) {
					if (typeof(callback) == "function") callback(false);
				};
			},
			fail: () => {
				if (typeof(callback) == "function") callback(false);
			}
		});
	},
	// 时间戳转时间格式化
	timestampToFormattedDateTime(timestamp) {
		// 创建一个Date对象并传递时间戳作为参数
		var dateObj = new Date(timestamp);
		// 获取年、月、日、时、分
		var year = dateObj.getFullYear();
		var month = ("0" + (dateObj.getMonth() + 1)).slice(-2);
		var day = ("0" + dateObj.getDate()).slice(-2);
		var hour = ("0" + dateObj.getHours()).slice(-2);
		var minute = ("0" + dateObj.getMinutes()).slice(-2);
		// 构建时间字符串
		var timeString = year + "-" + month + "-" + day + " " + hour + ":" + minute;
		return timeString;
	},
	// 时间戳转多少时间前
	timestampToTimeAgo(timestamp) {
		// 入参校验
		if (!timestamp || isNaN(timestamp)) {
			return "-";
		}

		// 定义时间单位
		var seconds = Math.floor((new Date() - timestamp) / 1000);
		var minutes = Math.floor(seconds / 60);
		var hours = Math.floor(minutes / 60);
		var days = Math.floor(hours / 24);
		var months = Math.floor(days / 30);
		var years = Math.floor(months / 12);

		if (seconds < 60) {
			return "刚刚";
		} else if (minutes < 60) {
			return minutes + "分钟前";
		} else if (hours < 24) {
			return hours + "小时前";
		} else if (days < 30) {
			return days + "天前";
		} else if (months < 12) {
			return months + "个月前";
		} else {
			return years + "年前";
		}
	},
};